==> ec2init-0.11-py3-none-any.whl: ec2init/plans/preinit/configure_dns.py <==
import logging
from os import path
import pathlib
import configparser

from typing import List, Optional

from ec2init import Procedure
from ec2init.utils.system import SystemUtils, OSType
from ec2init.plans.plan_utils import HopsPlanUtils
from ec2init.utils.cloud import get_cloud_provider
from ec2init.plans.multinode.seds import Seds
from ec2init.utils.backup_information import BackupInformation

logger = logging.getLogger(__name__)

class CentosConfigureDNS(Procedure):
    RESOLV_CONF = "/etc/resolv.conf"
    DNSMASQ_RESOLV_CONF = "/srv/dnsmasq/resolv.conf"

    def __init__(self, name: str, config: configparser.ConfigParser, plan_utils: HopsPlanUtils, cloud_provider: str, backup_info: BackupInformation) -> None:
        self.name = name
        self.config = config
        self.plan_utils = plan_utils
        self.cloud_provider = cloud_provider
        self.backup_info = backup_info

    @staticmethod
    def should_configure(plan_utils: HopsPlanUtils) -> bool:
        if SystemUtils.get_os_type() != OSType.CENTOS:
            return False

        check_file = plan_utils.get_procedure_check_file(CentosConfigureDNS.__name__)
        if plan_utils.check_file_exists(check_file):
            return False

        return True

    # We can't make any callbacks before we configure DNS
    def pre(self) -> None:
        pass

    def execute(self) -> List[Procedure]:
        logger.info(f"{self.name} - Starting execution")

        cmd = f"chattr -i {CentosConfigureDNS.RESOLV_CONF}"
        SystemUtils.execute_command(cmd.split(" "))

        # Let dhclient reconfigure dns
        logger.info(f"{self.name} - Reconfiguring DNS")
        SystemUtils.execute_command(["dhclient"])

        # We must have the absolute path to cp because the Centos has an alias
        # which is always interactive
        cmd = f"/usr/bin/cp -f --preserve=all {CentosConfigureDNS.RESOLV_CONF} {CentosConfigureDNS.DNSMASQ_RESOLV_CONF}"
        SystemUtils.execute_command(cmd.split(" "))

        logger.debug(f"{self.name} - Getting my private IP")
        local_ip = get_cloud_provider(self.cloud_provider).get_private_ip(self.config)
        logger.debug(f"{self.name} - My private IP is: {local_ip}")
        with open(CentosConfigureDNS.RESOLV_CONF, 'w') as fd:
            fd.write(f"nameserver {local_ip}")

        cmd = f"chattr +i {CentosConfigureDNS.RESOLV_CONF}"
        SystemUtils.execute_command(cmd.split(" "))
        logger.info(f"{self.name} - Finished reconfiguring resolv.conf")

        logger.debug(f"{self.name} - Fixing private IP in dnsmasq configuration")
        placeholder = self.backup_info.ip if BackupInformation.is_backup(self.backup_info) else Seds.NODE_IP
        regex = f"s/{placeholder}/{local_ip}/g"
        cmd = Seds.REPLACE.format(regex, '/etc/dnsmasq.d/default')
        logger.debug("%s - Replacing IP in /etc/dnsmasq.d/default", self.name)
        SystemUtils.execute_command(cmd.split(" "))
        logger.info("%s - Replaced %s in /etc/dnsmasq.d/default", self.name, local_ip)

        cmd = "systemctl restart dnsmasq"
        SystemUtils.execute_command(cmd.split(" "))

        self._done()
        logger.info(f"{self.name} - Finished execution")

        return []

    def _done(self) -> None:
        check_file = self.plan_utils.get_procedure_check_file(CentosConfigureDNS.__name__)
        check_file.touch()

    def rollback(self) -> None:
        pass

==> ec2init-0.17-py3-none-any.whl: ec2init/plans/preinit/configure_dns.py <==
import logging
from os import path
import pathlib
import configparser

from typing import List, Optional

from ec2init import Procedure
from ec2init.utils.system import SystemUtils, OSType
from ec2init.plans.plan_utils import HopsPlanUtils
from ec2init.utils.cloud import get_cloud_provider
from ec2init.plans.multinode.seds import Seds

logger = logging.getLogger(__name__)

class CentosConfigureDNS(Procedure):
    RESOLV_CONF = "/etc/resolv.conf"
    DNSMASQ_RESOLV_CONF = "/srv/dnsmasq/resolv.conf"

    def __init__(self, name: str, config: configparser.ConfigParser, plan_utils: HopsPlanUtils, cloud_provider: str) -> None:
        self.name = name
        self.config = config
        self.plan_utils = plan_utils
        self.cloud_provider = cloud_provider

    @staticmethod
    def should_configure(plan_utils: HopsPlanUtils) -> bool:
        if SystemUtils.get_os_type() != OSType.CENTOS:
            return False

        check_file = plan_utils.get_procedure_check_file(CentosConfigureDNS.__name__)
        return plan_utils.check_file_exists(check_file)

    # We can't make any callbacks before we configure DNS
    def pre(self) -> None:
        pass

    def execute(self) -> List[Procedure]:
        logger.info(f"{self.name} - Starting execution")

        cmd = f"chattr -i {CentosConfigureDNS.RESOLV_CONF}"
        SystemUtils.execute_command(cmd.split(" "))

        # Let dhclient reconfigure dns
        logger.info(f"{self.name} - Reconfiguring DNS")
        SystemUtils.execute_command(["dhclient"])

        # We must have the absolute path to cp because the Centos has an alias
        # which is always interactive
        cmd = f"/usr/bin/cp -f --preserve=all {CentosConfigureDNS.RESOLV_CONF} {CentosConfigureDNS.DNSMASQ_RESOLV_CONF}"
        SystemUtils.execute_command(cmd.split(" "))

        logger.debug(f"{self.name} - Getting my private IP")
        local_ip = get_cloud_provider(self.cloud_provider).get_private_ip(self.config)
        logger.debug(f"{self.name} - My private IP is: {local_ip}")
        with open(CentosConfigureDNS.RESOLV_CONF, 'w') as fd:
            fd.write(f"nameserver {local_ip}")

        cmd = f"chattr +i {CentosConfigureDNS.RESOLV_CONF}"
        SystemUtils.execute_command(cmd.split(" "))
        logger.info(f"{self.name} - Finished reconfiguring resolv.conf")

        logger.debug(f"{self.name} - Fixing private IP in dnsmasq configuration")
        regex = f"s/{Seds.NODE_IP}/{local_ip}/g"
        cmd = Seds.REPLACE.format(regex, '/etc/dnsmasq.d/default')
        logger.debug("%s - Replacing IP in /etc/dnsmasq.d/default", self.name)
        SystemUtils.execute_command(cmd.split(" "))
        logger.info("%s - Replaced %s in /etc/dnsmasq.d/default", self.name, local_ip)

        cmd = "systemctl restart dnsmasq"
        SystemUtils.execute_command(cmd.split(" "))

        self._done()
        logger.info(f"{self.name} - Finished execution")

        return []

    def _done(self) -> None:
        check_file = self.plan_utils.get_procedure_check_file(CentosConfigureDNS.__name__)
        check_file.touch()

    def rollback(self) -> None:
        pass
